@@ -22,11 +22,11 @@
 #include <sys/types.h>
 #include <curl/curl.h>
 
-#define LIBMRSS_VERSION_STRING  "0.18.0"
+#define LIBMRSS_VERSION_STRING  "0.19.1"
 
 #define LIBMRSS_MAJOR_VERSION   0
-#define LIBMRSS_MINOR_VERSION   18
-#define LIBMRSS_MICRO_VERSION   0
+#define LIBMRSS_MINOR_VERSION   19
+#define LIBMRSS_MICRO_VERSION   1
 
 #ifdef  __cplusplus
 extern "C" {
@@ -70,8 +70,12 @@ typedef enum {
 
   /** Set the title to a mrss_t element - the value is a string */
   MRSS_FLAG_TITLE,
+  /** Set the title type to a mrss_t element - the value is a string (ex: text, html, ...)*/
+  MRSS_FLAG_TITLE_TYPE,
   /** Set the description to a mrss_t element - the value is a string */
   MRSS_FLAG_DESCRIPTION,
+  /** Set the description type to a mrss_t element - the value is a string */
+  MRSS_FLAG_DESCRIPTION_TYPE,
   /** Set the link to a mrss_t element - the value is a string */
   MRSS_FLAG_LINK,
   /** Set the id to a mrss_t element - the value is a string */
@@ -82,6 +86,8 @@ typedef enum {
   MRSS_FLAG_RATING,
   /** Set the copyright to a mrss_t element - the value is a string */
   MRSS_FLAG_COPYRIGHT,
+  /** Set the copyright type to a mrss_t element - the value is a string */
+  MRSS_FLAG_COPYRIGHT_TYPE,
   /** Set the pubDate to a mrss_t element - the value is a string */
   MRSS_FLAG_PUBDATE,
   /** Set the lastBuildDate to a mrss_t element - the value is a string */
@@ -186,12 +192,18 @@ typedef enum {
 
   /** Set the title to a mrss_item_t element - the value is a string */
   MRSS_FLAG_ITEM_TITLE,
+  /** Set the title type to a mrss_item_t element - the value is a string */
+  MRSS_FLAG_ITEM_TITLE_TYPE,
   /** Set the link to a mrss_item_t element - the value is a string */
   MRSS_FLAG_ITEM_LINK,
   /** Set the description to a mrss_item_t element - the value is a string */
   MRSS_FLAG_ITEM_DESCRIPTION,
+  /** Set the description type to a mrss_item_t element - the value is a string */
+  MRSS_FLAG_ITEM_DESCRIPTION_TYPE,
   /** Set the copyright to a mrss_item_t element - the value is a string */
   MRSS_FLAG_ITEM_COPYRIGHT,
+  /** Set the copyright type to a mrss_item_t element - the value is a string */
+  MRSS_FLAG_ITEM_COPYRIGHT_TYPE,
 
   /** Set the author to a mrss_item_t element - the value is a string */
   MRSS_FLAG_ITEM_AUTHOR,
@@ -288,9 +300,12 @@ struct mrss_item_t {
 
   				/* 0.91	0.92	1.0	2.0	ATOM	*/
   char *title;			/* R	O	O	O	R	*/
+  char *title_type;		/* -	-	-	-	O	*/
   char *link;			/* R	O	O	O	O	*/
   char *description;		/* R	O	-	O	O	*/
+  char *description_type;	/* -	-	-	-	0	*/
   char *copyright;		/* -	-	-	-	O	*/
+  char *copyright_type;		/* -	-	-	-	O	*/
   
   char *author;			/* -	-	-	O	O	*/
   char *author_uri;		/* -	-	-	-	O	*/
@@ -386,12 +401,15 @@ struct mrss_t {
   mrss_version_t version;	/* 0.91	0.92	1.0	2.0	ATOM	*/
 
   char *title;			/* R	R	R	R	R	*/
+  char *title_type;		/* -	-	-	-	O	*/
   char *description;		/* R	R	R	R	R	*/
+  char *description_type;	/* -	-	-	-	O	*/
   char *link;			/* R	R	R	R	O	*/
   char *id;			/* 	-	-	-	-	O	*/
   char *language;		/* R	O	-	O	O	*/
   char *rating;			/* O	O	-	O	-	*/
   char *copyright;		/* O	O	-	O	O	*/
+  char *copyright_type;		/* -	-	-	-	O	*/
   char *pubDate;		/* O	O	-	O	-	*/
   char *lastBuildDate;		/* O	O	-	O	O	*/
   char *docs;			/* O	O	-	O	-	*/
@@ -554,6 +572,25 @@ mrss_error_t	mrss_parse_url_with_options_and_error
 					 mrss_options_t	* options,
 					 CURLcode *	curlcode);
 
+/**
+ * Like the previous function but you take ownership of the downloaded buffer
+ * in case of success
+ * \param url The url to be parsed
+ * \param mrss the pointer to your data struct
+ * \param options a pointer to a options data struct
+ * \param curlcode the error code from libcurl
+ * \param feed_content a pointer to the buffer with the document. This is not NULL terminated
+ * \param feed_size the size of the buffer above
+ * \return the error code
+ */
+mrss_error_t	mrss_parse_url_with_options_error_and_transfer_buffer
+					(char *		url,
+					 mrss_t **	mrss,
+					 mrss_options_t	* options,
+					 CURLcode *	curlcode,
+					 char **	feed_content,
+					 int  *		feed_size);
+
 /** 
  * Parses a file and creates the data struct of the feed RSS url
  * \param file The file to be parsed
