@@ -9,6 +9,7 @@ main (int argc, char **argv)
   mrss_error_t ret;
   mrss_item_t *item;
   mrss_tag_t *tag;
+  CURLcode code;
 
   if (argc != 2)
     {
@@ -18,14 +19,17 @@ main (int argc, char **argv)
       return 1;
     }
 
-  if (!strncmp (argv[1], "http://", 7))
-    ret = mrss_parse_url (argv[1], &data);
+  if (!strncmp (argv[1], "http://", 7) || !strncmp (argv[1], "https://", 8))
+    ret = mrss_parse_url_with_options_and_error (argv[1], &data, NULL, &code);
   else
     ret = mrss_parse_file (argv[1], &data);
 
   if (ret)
     {
-      fprintf (stderr, "MRSS return error: %s\n", mrss_strerror (ret));
+      fprintf (stderr, "MRSS return error: %s\n",
+	       ret ==
+	       MRSS_ERR_DOWNLOAD ? mrss_curl_strerror (code) :
+	       mrss_strerror (ret));
       return 1;
     }
 
